<?php
/**
 * Setup suggested plugin system.
 *
 * Include the StarterBlog_Plugin_Manager class and add
 * an interface for users to to manage suggested
 * plugins.
 *
 * @since 1.0.2
 *
 * @see  StarterBlog_Plugin_Manager
 * @link http://mypluginmanager.com
 */
function starterblog_plugin_manager() {

	if ( ! is_admin() ) {
		return;
	}

	/*
	 * Setup suggested plugins.
	 *
	 * It's a good idea to have a filter applied to this so your
	 * loyal users running child themes have a way to easily modify
	 * which plugins show as suggested for the site they're setting
	 * up for a client.
	 */
	$plugins = apply_filters( 'starterblog_plugins', array(
		array(
			'name'    => __('JetPack by Automattic', 'starter-blog'),	
			'slug'    => 'jetpack',
		),
		array(
			'name'    => __('WP Page Builder by Themeum', 'starter-blog'),
			'slug'    => 'wp-pagebuilder',
        ),
	));

	/*
	 * Setup optional arguments for plugin manager interface.
	 *
	 * See the set_args() method of the StarterBlog_Plugin_Manager
	 * class for full documentation on what you can pass in here.
	 */
	$args = array(
		'page_title' => __( 'Suggested Plugins by StarterBlog Theme', 'starter-blog' ),
		'menu_slug'  => 'starterblog-suggested-plugins',
	);

	/*
	 * Create plugin manager object, passing in the suggested
	 * plugins and optional arguments.
	 */
	$manager = new StarterBlog_Plugin_Manager( $plugins, $args );

}
add_action( 'after_setup_theme', 'starterblog_plugin_manager' );